@@ -2,7 +2,7 @@
    system math.h classification macros.
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2009-2014 Free Software Foundation, Inc.
+   Copyright (C) 2009-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -44,15 +44,10 @@
 __BEGIN_DECLS
 
 #define DEC_INFINITY	__builtin_infd32()
-#define DEC_NAN		(0.0DF * DEC_INFINITY)
+#define DEC_NAN		__builtin_nand32("")
+#define HUGE_VAL_D32	__builtin_infd32()
 #define HUGE_VAL_D64	__builtin_infd64()
-
-/* #define DEC_INFINITY   (9999999.E96DF + 1.E96df)
- * #define DEC_NAN (0.0DF * DEC_INFINITY)
- * #define HUGE_VAL_D64   (9.999999999999999E384DD + 1.E384dd) */
-
-#define HUGE_VAL_D32	HUGE_VAL_D64
-#define HUGE_VAL_D128	HUGE_VAL_D64
+#define HUGE_VAL_D128	__builtin_infd128()
 
 /* This method works for both the GCC and the XLC compilers for detecting
  * whether a value is a Decimal Floating Point type.  */
@@ -77,6 +72,13 @@ __BEGIN_DECLS
 /* We need the definition of _Bool.  */
 #include <stdbool.h>
 
+#ifndef FP_LLOGB0
+# define FP_LLOGB0 LONG_MIN+1
+#endif
+#ifndef FP_LLOGBNAN
+# define FP_LLOGBNAN LONG_MAX
+#endif
+
 extern _Decimal32 acosd32 (_Decimal32 __x) __THROW;
 extern _Decimal32 __acosd32 (_Decimal32 __x) __THROW;
 
