@@ -2,7 +2,7 @@
 
    Copyright (C) 2001 Stephen L. Moshier <moshier@na-net.ornl.gov>
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2001, 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2001-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -181,7 +181,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE x)
     return x+x;
 
   sign = (x > 0.0DL)?0:1;
-  ix = FUNC_D(fabs) (x);
+  ix = FUNC_D(__fabs) (x);
 
   if (ix >= 1.0DL)		/* |x| >= 1 */
     {
@@ -296,7 +296,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE x)
   else
     {				/* |x| >= .625 */
       z = (one - ix) * 0.5DL;
-      s = sqrtd128 (z);
+      s = __sqrtd128 (z);
       /* Compute an extended precision square root from
 	 the Newton iteration  s -> 0.5 * (s + z / s).
          The change w from s to the improved value is
