@@ -1,7 +1,7 @@
 /* Returns the unbiased exponent of the passed _Decimal32 value as an int
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -35,11 +35,17 @@
 #ifndef _MAX_VALUE
 #  define _MAX_VALUE   INT_MAX
 #endif
-
 #ifndef _MIN_VALUE
 #  define _MIN_VALUE   INT_MIN
 #endif
 
+#ifndef _FBLOG0
+#  define _FBLOG0      FP_ILOGB0
+#endif
+#ifndef _FBLOGNAN
+#  define _FBLOGNAN    FP_ILOGBNAN
+#endif
+
 #include <decContext.h>
 #include <decNumber.h>
 #include <math.h>
@@ -63,41 +69,52 @@ INTERNAL_FUNCTION_NAME (DEC_TYPE x)
   decNumber dn_x;
   decNumber dn_absx;
   decNumber dn_logx;
+  decNumber dn_one;
+  decNumber dn_cmp;
+  enum rounding round;
 
   FUNC_CONVERT_TO_DN (&x, &dn_x);
-  if (___decNumberIsZero (&dn_x))
+  if (decNumberIsZero (&dn_x))
     {
       DFP_EXCEPT (FE_INVALID);
       DFP_ERRNO (EDOM);
-      return FP_ILOGB0;
+      return _FBLOG0;
     }
-  if (___decNumberIsInfinite (&dn_x))
+  if (decNumberIsInfinite (&dn_x))
     {
       DFP_EXCEPT (FE_INVALID);
       DFP_ERRNO (EDOM);
-      return ___decNumberIsNegative (&dn_x) ? _MIN_VALUE : _MAX_VALUE;
+      return decNumberIsNegative (&dn_x) ? _MIN_VALUE : _MAX_VALUE;
     }
-  if (___decNumberIsNaN (&dn_x))
+  if (decNumberIsNaN (&dn_x))
     {
       DFP_EXCEPT (FE_INVALID);
       DFP_ERRNO (EDOM);
-      return FP_ILOGBNAN;
+      return _FBLOGNAN;
     }
 
-  ___decContextDefault (&context, DEFAULT_CONTEXT);
+  decContextDefault (&context, DEFAULT_CONTEXT);
 
-  ___decNumberAbs (&dn_absx, &dn_x, &context);
+  decNumberAbs (&dn_absx, &dn_x, &context);
 
-  /*  For DFP, we use radix 10 instead of whatever FLT_RADIX
-     happens to be */
-  ___decNumberLog10 (&dn_logx, &dn_absx, &context);
+  /* For DFP, we use radix 10 instead of whatever FLT_RADIX happens to be */
+  decNumberLog10 (&dn_logx, &dn_absx, &context);
 
-  /* Capture the case where truncation will return the wrong result.  */
-  if (x < DFP_CONSTANT (1.0) && x > DFP_CONSTANT (-1.0))
-    context.round = DEC_ROUND_UP;	/* round away from zero  */
-  else
-    context.round = DEC_ROUND_DOWN;	/*  truncate */
-  ___decNumberToIntegralValue (&dn_result, &dn_logx, &context);
+  /* Capture the case where truncation will return the wrong result,
+     by rounding up if -1.0 < x < 1.0  */
+  round = DEC_ROUND_DOWN;
+  decNumberFromInt32 (&dn_one, 1);
+  decNumberCompare (&dn_cmp, &dn_x, &dn_one, &context);
+  if (-decNumberIsNegative(&dn_cmp))
+    {
+      decNumberFromInt32 (&dn_one, -1);
+      decNumberCompare (&dn_cmp, &dn_x, &dn_one, &context);
+      if (!decNumberIsNegative(&dn_cmp) && !decNumberIsZero(&dn_cmp))
+	round = DEC_ROUND_UP;
+    }
+  context.round = round;
+
+  decNumberToIntegralValue (&dn_result, &dn_logx, &context);
 
   FUNC_CONVERT_FROM_DN (&dn_result, &result, &context);
   /* Use _Decimal* to int casting.  */
