@@ -1,7 +1,7 @@
 /* Internal ieee754r function prototypes used by libdfp.
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -72,4 +72,12 @@ hidden_proto(__fpclassifyd32)
 hidden_proto(__fpclassifyd64)
 hidden_proto(__fpclassifyd128)
 
+hidden_proto(__fabsd32)
+hidden_proto(__fabsd64)
+hidden_proto(__fabsd128)
+
+hidden_proto(__signbitd32)
+hidden_proto(__signbitd64)
+hidden_proto(__signbitd128)
+
 #endif /* _IEEE754R_PRIVATE_H  */
