@@ -1,5 +1,5 @@
 /* Local definitions for the decNumber C Library.
-   Copyright (C) 2007-2014 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
    Contributed by IBM Corporation.  Author Mike Cowlishaw.
 
    This file is part of GCC.
@@ -57,6 +57,7 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
   #if !defined(DECUSE64)
   #define DECUSE64  1	      /* 1=use int64s, 0=int32 & smaller only */
   #endif
+  /*#define DECUSE128  1*/    /* 1=use int128s                        */
 
   /* Conditional check flags -- set these to 0 for best performance   */
   #if !defined(DECCHECK)
@@ -95,6 +96,9 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
   #define Long	 int64_t
   #define uLong  uint64_t
   #endif
+  #if DECUSE128
+  #include "decUInt128.h"
+  #endif
 
   /* Development-use definitions				      */
   typedef long int LI;	      /* for printf arguments only	      */
@@ -110,7 +114,6 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
   extern const uByte  DECSTICKYTAB[10]; /* re-round digits if sticky  */
   extern const uInt   DECPOWERS[10];	/* powers of ten table	      */
   /* The following are included from decDPD.h			      */
-  #include "decDPDSymbols.h"
   extern const uShort DPD2BIN[1024];	/* DPD -> 0-999 	      */
   extern const uShort BIN2DPD[1000];	/* 0-999 -> DPD 	      */
   extern const uInt   DPD2BINK[1024];	/* DPD -> 0-999000	      */
@@ -364,7 +367,6 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
   #define DFISSNAN(df)	  ((DFWORD(df, 0)&0x7e000000)==0x7e000000)
 
   /* Shared lookup tables					      */
-#include "decCommonSymbols.h"
   extern const uInt   DECCOMBMSD[64];	/* Combination field -> MSD   */
   extern const uInt   DECCOMBFROM[48];	/* exp+msd -> Combination     */
 
