@@ -44,17 +44,17 @@ const struct ieee754r_c_field c_decoder[32] = {
 
 /* Table to encode the "left most" 2 bits of the biased exponent and the
    "Left Most Digit" into the "C"ombination field.  Indexed by [lmd,lm2bits].  */
-const unsigned char lm2lmd_to_c[10][3] = {
-    {0x00, 0x08, 0x10}, 
-    {0x01, 0x09, 0x11},
-    {0x02, 0x0a, 0x12},
-    {0x03, 0x0b, 0x13},
-    {0x04, 0x0c, 0x14},
-    {0x05, 0x0d, 0x15},
-    {0x06, 0x0e, 0x16},
-    {0x07, 0x0f, 0x17},
-    {0x18, 0x1a, 0x1c},
-    {0x19, 0x1b, 0x1d}};  
+const unsigned char lm2lmd_to_c[10][4] = {
+    {0x00, 0x08, 0x10, 0x1e},
+    {0x01, 0x09, 0x11, 0x1e},
+    {0x02, 0x0a, 0x12, 0x1e},
+    {0x03, 0x0b, 0x13, 0x1e},
+    {0x04, 0x0c, 0x14, 0x1e},
+    {0x05, 0x0d, 0x15, 0x1e},
+    {0x06, 0x0e, 0x16, 0x1e},
+    {0x07, 0x0f, 0x17, 0x1e},
+    {0x18, 0x1a, 0x1c, 0x1e},
+    {0x19, 0x1b, 0x1d, 0x1e}};
 
 /* Table to convert 3 Densely Packed Decimal digits (10-bits) into
    3 ASCII digits (24-bits, 3 bytes).  */
