@@ -1,7 +1,7 @@
 /* Number of digits functions.
 
    Copyright (C) 2006, 2007, 2008 IBM Corporation.
-   Copyright (C) 2007-2014, Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -74,15 +74,16 @@ FUNC_D (getexp) (DEC_TYPE x)
 # define DECIMAL_DEC_BITS  DECIMAL128_BEC_bits
 #endif
 
-  c_f =  c_decoder[d.ieee.c];
-  exp = c_f.lm_exp << DECIMAL_DEC_BITS;
+  c_f  =  c_decoder[d.ieee.c];
+  /* PowerPC dxex instruction returns -1 for infinity and -2 for NaN.  */
+  if (c_f.is_inf)
+    return -1 - DECIMAL_BIAS;
+  else if (c_f.is_nan)
+    return -2 - DECIMAL_BIAS;
+  exp  = c_f.lm_exp << DECIMAL_DEC_BITS;
   exp += d.ieee.bec;
   exp -= DECIMAL_BIAS;
 
-  /* Hardware DFP returns -2 = DECIMAL*_BIAS for a NaN. Be congruent with that.  */
-  if (exp == -DECIMAL_BIAS)
-    return --exp;
-
   return exp;
 }
 #define SETEXP_NAME	PASTE(setexp,PASTE(d,_DECIMAL_SIZE))
@@ -184,13 +185,13 @@ FUNC_D (numdigits) (DEC_TYPE x)
   int firstdigit = 0;
   int len = 0;
 #if _DECIMAL_SIZE == 32
-  char digits[8];
+  char digits[NDIGITS_32];
   __get_digits_d32(x, digits, NULL, NULL, NULL, NULL);
 #elif _DECIMAL_SIZE == 64
-  char digits[17];
+  char digits[NDIGITS_64];
   __get_digits_d64(x, digits, NULL, NULL, NULL, NULL);
 #elif _DECIMAL_SIZE == 128
-  char digits[35];
+  char digits[NDIGITS_128];
   __get_digits_d128(x, digits, NULL, NULL, NULL, NULL);
 #endif
   while (digits[firstdigit] == '0') firstdigit++;
@@ -205,24 +206,52 @@ static inline DEC_TYPE
 FUNC_D (left_justify) (DEC_TYPE x)
 {
   int firstdigit = 0, len;
+#undef decfield
 #if _DECIMAL_SIZE == 32
-  char digits[8+7];
+# define decfield sd
+  union ieee754r_Decimal32 mask = { .si = 0x7c000001 };
+  char digits[NDIGITS_32+NDIGITS_32-1];
   __get_digits_d32(x, digits, NULL, NULL, NULL, NULL);
 #elif _DECIMAL_SIZE == 64
-  char digits[17+16];
+# define decfield dd
+  union ieee754r_Decimal64 mask = { .di = {
+#  if __BYTE_ORDER == __LITTLE_ENDIAN
+    0x00000001, 0x7c000000
+#  else
+    0x7c000000, 0x00000001
+#endif
+  } };
+  char digits[NDIGITS_64+NDIGITS_64-1];
   __get_digits_d64(x, digits, NULL, NULL, NULL, NULL);
 #elif _DECIMAL_SIZE == 128
-  char digits[35+34];
+# define decfield td
+  union ieee754r_Decimal128 mask = { .ti = {
+#  if __BYTE_ORDER == __LITTLE_ENDIAN
+    0x00000001, 0x0, 0x0, 0x7c000000 } };
+#  else
+    0x7c000000, 0x0, 0x0, 0x00000001 } };
+#endif
+  char digits[NDIGITS_128+NDIGITS_128-1];
   __get_digits_d128(x, digits, NULL, NULL, NULL, NULL);
 #endif
   while (digits[firstdigit] == '0') firstdigit++;
   len = strlen(digits + firstdigit);
   if (len)
     {
+      int exp = FUNC_D (getexp) (x);
       /* pad the significant digits with enough trailing zeroes */
-      memset(digits + firstdigit + len, '0', firstdigit);
+      if ((exp - firstdigit) < -DECIMAL_BIAS)
+       {
+         firstdigit = DECIMAL_BIAS + exp;
+         /* If the number overflows the data it will become a NaN. */
+         if ((exp - firstdigit) <= -DECIMAL_BIAS && (firstdigit != 0))
+           return mask.decfield;
+       }
+      if (firstdigit)
+	memset (digits + firstdigit + len, '0', firstdigit);
       x = FUNC_D (setdigits) (x, digits + firstdigit);
       x = FUNC_D(setexp) (x, FUNC_D (getexp) (x) - firstdigit);
+      x = FUNC_D(setexp) (x, exp - firstdigit);
     }
 
   return x;
