@@ -1,6 +1,6 @@
 /* Test facility scaffolding.
 
-   Copyright (C) 2009, 2011, 2011 Free Software Foundation, Inc.
+   Copyright (C) 2009-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -32,6 +32,7 @@ static int testnum = 0;
 #ifndef _SC
 #include <string.h>
 #include <stdarg.h>
+#include <math.h>
 #include <limits.h> /* For CHAR_MAX.  */
 
 /* Generally don't invoke this directly unless you already have __LINE__ set in
@@ -152,7 +153,7 @@ static int testnum = 0;
 
 
 #ifdef _WANT_PC
-static char buf[CHAR_MAX];
+static char buf[1024];
 #ifndef _PC
 
 /* _PC == Printf_dfp Compare with Position  */
